#
# spec file for package HaRe
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name HaRe
%bcond_with tests
Name:           %{pkg_name}
Version:        0.8.4.1
Release:        10.1
Summary:        The Haskell Refactorer
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-Strafunski-StrategyLib-devel
BuildRequires:  ghc-cabal-helper-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-ghc-devel
BuildRequires:  ghc-ghc-exactprint-devel
BuildRequires:  ghc-ghc-mod-devel
BuildRequires:  ghc-ghc-syb-utils-devel
BuildRequires:  ghc-gitrev-devel
BuildRequires:  ghc-hslogger-devel
BuildRequires:  ghc-monad-control-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-optparse-applicative-devel
BuildRequires:  ghc-optparse-simple-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-syb-devel
BuildRequires:  ghc-syz-devel
%if %{with tests}
BuildRequires:  ghc-Diff-devel
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-base-prelude-devel
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-conversion-case-insensitive-devel
BuildRequires:  ghc-conversion-devel
BuildRequires:  ghc-conversion-text-devel
BuildRequires:  ghc-foldl-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-turtle-devel
%endif

%description
A Haskell 2010 refactoring tool. HaRe supports the full Haskell 2010 standard,
through making use of the GHC API.

Version 0.7.2.8 supports up to GHC 7.6.3.

There is no support for GHC 7.8.x. There will never be support for GHC 7.8.x

From version 0.8.0.0, GHC 7.10.2 is supported.

From version 0.8.3.0, GHC 8.0.1 is supported.

From version 0.8.4.0, GHC 8.0.2 is supported.

It is tested against GHC 7.10.3, GHC 8.0.1 and GHC 8.0.2 (via travis-ci.org)

It currently only has emacs integration built in, community input welcome for
others.

HaRe attempts to operate in a safe way, by first writing new files with
proposed changes, and only swapping these with the originals when the change is
accepted. In the process the original file is renamed to have the current
date/time as a suffix. Thus it should be possible to (manually) undo changes.

Even so, it is strongly advised to back up any source files before refactoring,
as we can make no promises as to the reliability of this tool. Use at your own
risk.

At the moment parsing of any file with FFI exports will fail.

See Language.Haskell.Refact.HaRe for the current list of refactorings supported
.

%package -n ghc-%{name}
Summary:        Haskell %{name} library
Group:          System/Libraries

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.

%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Group:          Development/Libraries/Haskell
Requires:       ghc-%{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.

%prep
%setup -q

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post -n ghc-%{name}-devel
%ghc_pkg_recache

%postun -n ghc-%{name}-devel
%ghc_pkg_recache

%files
%doc LICENSE
%doc ChangeLog
%{_bindir}/ghc-hare
%dir %{_datadir}/%{name}-%{version}
%dir %{_datadir}/%{name}-%{version}/elisp
%dir %{_datadir}/%{name}-%{version}/test
%dir %{_datadir}/%{name}-%{version}/test/testdata
%dir %{_datadir}/%{name}-%{version}/test/testdata/AddOneParameter
%dir %{_datadir}/%{name}-%{version}/test/testdata/Case
%dir %{_datadir}/%{name}-%{version}/test/testdata/Demote
%dir %{_datadir}/%{name}-%{version}/test/testdata/DupDef
%dir %{_datadir}/%{name}-%{version}/test/testdata/FreeAndDeclared
%dir %{_datadir}/%{name}-%{version}/test/testdata/Layout
%dir %{_datadir}/%{name}-%{version}/test/testdata/LiftOneLevel
%dir %{_datadir}/%{name}-%{version}/test/testdata/LiftToToplevel
%dir %{_datadir}/%{name}-%{version}/test/testdata/MoveDef
%dir %{_datadir}/%{name}-%{version}/test/testdata/Renaming
%dir %{_datadir}/%{name}-%{version}/test/testdata/RmOneParameter
%dir %{_datadir}/%{name}-%{version}/test/testdata/Simple
%dir %{_datadir}/%{name}-%{version}/test/testdata/SwapArgs
%dir %{_datadir}/%{name}-%{version}/test/testdata/TH
%dir %{_datadir}/%{name}-%{version}/test/testdata/TypeUtils
%dir %{_datadir}/%{name}-%{version}/test/testdata/Visible
%dir %{_datadir}/%{name}-%{version}/test/testdata/cabal
%dir %{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal1
%dir %{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal1/src
%dir %{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal1/src/Foo
%dir %{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal2
%dir %{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal2/src
%dir %{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal2/src/Foo
%dir %{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal3
%dir %{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal3/src
%dir %{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal3/src/Foo
%dir %{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal4
%dir %{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal4/src
%dir %{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal4/src/Foo
%dir %{_datadir}/%{name}-%{version}/test/testdata/cabal/foo
%dir %{_datadir}/%{name}-%{version}/test/testdata/cabal/foo/src
%dir %{_datadir}/%{name}-%{version}/test/testdata/cabal/foo/src/Foo
%{_datadir}/%{name}-%{version}/elisp/*.el
%{_datadir}/%{name}-%{version}/configure.sh
%{_datadir}/%{name}-%{version}/test/testdata/*.cabal
%{_datadir}/%{name}-%{version}/test/testdata/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/AddOneParameter/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/AddOneParameter/*.expected.hs
%{_datadir}/%{name}-%{version}/test/testdata/Case/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/Case/*.hs.expected
%{_datadir}/%{name}-%{version}/test/testdata/Case/*.hs.expected.dd
%{_datadir}/%{name}-%{version}/test/testdata/Demote/*.expected.hs
%{_datadir}/%{name}-%{version}/test/testdata/Demote/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/Demote/*.hs.expected
%{_datadir}/%{name}-%{version}/test/testdata/DupDef/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/DupDef/*.hs.expected
%{_datadir}/%{name}-%{version}/test/testdata/DupDef/*.hs.expected.dd
%{_datadir}/%{name}-%{version}/test/testdata/DupDef/*.hs.expected.gg
%{_datadir}/%{name}-%{version}/test/testdata/DupDef/*.hs.expected.ll
%{_datadir}/%{name}-%{version}/test/testdata/DupDef/*.hs.expected.mm
%{_datadir}/%{name}-%{version}/test/testdata/DupDef/*.hs.expected.nn
%{_datadir}/%{name}-%{version}/test/testdata/FreeAndDeclared/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/Layout/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/Layout/*.hs.expected
%{_datadir}/%{name}-%{version}/test/testdata/LiftOneLevel/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/LiftOneLevel/*.hs.expected
%{_datadir}/%{name}-%{version}/test/testdata/LiftToToplevel/*.expected.hs
%{_datadir}/%{name}-%{version}/test/testdata/LiftToToplevel/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/LiftToToplevel/*.hs.expected
%{_datadir}/%{name}-%{version}/test/testdata/MoveDef/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/MoveDef/*.hs.expected
%{_datadir}/%{name}-%{version}/test/testdata/Renaming/*.expected.hs
%{_datadir}/%{name}-%{version}/test/testdata/Renaming/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/Renaming/*.hs.expected
%{_datadir}/%{name}-%{version}/test/testdata/RmOneParameter/*.expected.hs
%{_datadir}/%{name}-%{version}/test/testdata/RmOneParameter/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/Simple/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/Simple/*.hs.expected
%{_datadir}/%{name}-%{version}/test/testdata/SwapArgs/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/TH/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/TypeUtils/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/Visible/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal1/*.cabal
%{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal1/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal1/src/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal1/src/Foo/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal2/*.cabal
%{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal2/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal2/src/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal2/src/Foo/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal3/*.cabal
%{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal3/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal3/src/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal3/src/Foo/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal4/*.cabal
%{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal4/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal4/src/*.expected.hs
%{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal4/src/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal4/src/Foo/*.expected.hs
%{_datadir}/%{name}-%{version}/test/testdata/cabal/cabal4/src/Foo/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/cabal/foo/*.cabal
%{_datadir}/%{name}-%{version}/test/testdata/cabal/foo/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/cabal/foo/src/*.expected.hs
%{_datadir}/%{name}-%{version}/test/testdata/cabal/foo/src/*.hs
%{_datadir}/%{name}-%{version}/test/testdata/cabal/foo/src/Foo/*.expected.hs
%{_datadir}/%{name}-%{version}/test/testdata/cabal/foo/src/Foo/*.hs

%files -n ghc-%{name} -f ghc-%{name}.files
%doc LICENSE

%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%doc ChangeLog

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Fri Jul 28 2017 psimons@suse.com
- Update to version 0.8.4.1.
* Thu Jun  8 2017 psimons@suse.com
- Update to version 0.8.4.0 revision 2.
* Wed May 31 2017 psimons@suse.com
- Update to version 0.8.4.0 revision 1.
* Tue Mar 14 2017 psimons@suse.com
- Update to version 0.8.4.0 with cabal2obs.
